#!/bin/sh
# The /etc init.d and rc directories differ on UnitedLinux and Redhat

if [ -f /etc/redhat-release ]; then
        ibmproxy_link="/etc/rc.d/init.d/ibmproxy"
        rcdir="/etc"
        Levels="rc3.d/S88ibmproxy
                rc5.d/S88ibmproxy
                rc0.d/K54ibmproxy
                rc1.d/K54ibmproxy
                rc2.d/K54ibmproxy
                rc6.d/K54ibmproxy"
else
        ibmproxy_link="/etc/init.d/ibmproxy"
        rcdir="/etc/init.d"

        Levels="rc5.d/S20ibmproxy
                rc3.d/S20ibmproxy
                rc5.d/K20ibmproxy
                rc3.d/K20ibmproxy"
fi

# Create links to ibmproxy in the /etc ... rc directories.

ln -sf /opt/ibm/edge/cp/etc/en_US/ibmproxy ${ibmproxy_link}

for runlevel in ${Levels}; do
        ln -sf ${ibmproxy_link} ${rcdir}/${runlevel}
done

restore_files ()
{
TO_DIR=$1
NEW=$2
shift 2
for i in $*
do
        if [ -f $oldfiles_dir/$i ]
        then
                CONTINUE="Y"
                if [ "$NEW" = "TRUE" ]
                then
                        if [ -f $TO_DIR/${i} ]
                        then
                                cp -fp $TO_DIR/${i} $TO_DIR/${i}.new
                                if [ $? -ne 0 ]
                                then
                                        ERROR_COPYING="Y"
                                        CONTINUE="N"
                                fi
                        fi
                fi
                if [ "$CONTINUE" = "Y" ]
                then
                        cp -fp $oldfiles_dir/${i} $TO_DIR/${i}
                        if [ $? -eq 0 ]
                        then
                                COPYMADE=Y
                        else
                                ERROR_COPYING="Y"
                        fi
                fi
        fi
done
}

# restore config files

WES_HOME=/opt/ibm/edge
COMPONENT=cp
APP_HOME=$WES_HOME/$COMPONENT
COPYMADE="N"
ERROR_COPYING="N"

oldfiles_dir=$WES_HOME/oldfiles/$COMPONENT

# Reset permissions for webadmin files that may have been restored from
# oldfiles of previous versions. In some cases they were saved off incorrectly
# (without -p on cp command).

for i in webadmin.passwd webadmin.passwd.bak webadmin.group
do
   newowner=`ls -l /opt/ibm/edge/cp/server_root/protect/$i|awk '{print $3}'`
   newgroup=`ls -l /opt/ibm/edge/cp/server_root/protect/$i|awk '{print $4}'`

#  webadmin.passwd.bak files will be processed twice, but 2nd time counts
   chmod 775 /opt/ibm/edge/oldfiles/cp/$i* 2>/dev/null
   chown $newowner:$newgroup /opt/ibm/edge/oldfiles/cp/$i* 2>/dev/null
done

# Handle the special case for /etc/socks.conf
# If /etc/socks.conf is a link, and there is a saved copy,
# restore directly to /etc/socks.conf

if [ -h /etc/socks.conf ]
then
        if [ -f $oldfiles_dir/socks.conf ]
        then
                rm -f /etc/socks.conf
                cp $oldfiles_dir/socks.conf /etc/socks.conf
        fi
fi

#  Copy the following new files to .new before restoring over them.

DOT_NEW=TRUE

restore_files $APP_HOME/etc $DOT_NEW pacpolicy.conf paccp.conf pac.conf

# Cyberpatrol's setup_state file used to be only restored after a patch,
# because it should not be restored from WTE 3.6, only WSES 2.0 which has the
# the new /opt/ibm/edge install path in it.  That will be the predominant
# upgrade case now.

restore_files   $APP_HOME/server_root/filter/cyberpatrol $DOT_NEW setup_state

# Restore the following files directly into their destination.

DOT_NEW=FALSE

restore_files   $APP_HOME/server_root/filter/cyberpatrol $DOT_NEW \
                .cpauthinit registration.data

restore_files $APP_HOME/server_root/protect $DOT_NEW \
        webadmin.group webadmin.passwd webadmin.passwd.bak

restore_files $APP_HOME/server_root/data $DOT_NEW mappingtbl

if [ "${ERROR_COPYING}" = "Y" ]; then
        echo ""
        echo "Error copying configuration files from ${oldfiles_dir},"
        echo "not all old versions restored."
        echo ""
elif [ "${COPYMADE}" = "Y" ]; then
        echo ""
        echo "Configuration files have been restored"
        echo ""
fi
if [ ! -f /etc/socks.conf -a ! -h /etc/socks/conf ]; then
        ln -s /etc/socks.conf.exp /etc/socks.conf
fi
# Create the expiration file.
#
if [ ! -d /opt/ibm/edge/cp/expiry ] ; then
  mkdir -p /opt/ibm/edge/cp/expiry
fi

if [ -f /opt/ibm/edge/cp/sbin/newbomb ]; then
        /opt/ibm/edge/cp/sbin/newbomb
        rm -f /opt/ibm/edge/cp/sbin/newbomb
        touch /opt/ibm/edge/cp/sbin/newbomb
fi
# Start up the proxy
if [ -f /etc/redhat-release ]; then             # /etc/redhat-release
        /etc/rc.d/init.d/ibmproxy start > /dev/null 2>&1
else
        /etc/init.d/ibmproxy start > /dev/null 2>&1
fi

# check if the proxy was started
sleep 5
pid=`ps -e | grep ibmproxy | awk '{ print $1 }'`
if [ "$pid" != "" ] ; then
        printf "The proxy has been started and is functional.\n\n"
else
        printf "The proxy failed to start.\n\n"
fi
exit 0